@@ -62,16 +62,18 @@ class PointTorque(Load):
     Parameters:
     -----------
     force: float
-        Torque in kN.m
-        Note: named force for simplicity.
+        Torque load (default units N.m), (named force for consistency 
+        with other load types)
     coord: float
-        x coordinate of torque on beam
+        x coordinate of torque on beam (default units m)
 
     Examples
     ---------
-    >>> # 30 kN·m (clockwise) torque at x=4 m
+    >>> # 30 N·m (anti-clockwise) torque at x = 4 m
     >>> motor_torque = PointTorque(30, 4)
 
+    Note: Anti-clockwise is positive
+
     """
 
     def __init__(self, force=0, coord=0):
@@ -104,25 +106,23 @@ class PointLoad(Load):
     Parameters:
     -----------
     Force: float
-        Force in kN
+        Force load (default units m)
     coord: float
-        x coordinate of load on beam
+        x coordinate of load on beam (default units m)
     angle: float
         angle of point load where:
         - 0 degrees is purely horizontal +ve
         - 90 degrees is purely vertical +ve
         - 180 degrees is purely horizontal -ve of force sign specified.
 
-
     Examples
     --------
-    >>> # 10 kN towards the right at x=9 m
-    >>> external_force = PointLoad(10, 9, 90)
-    >>> # 30 kN downwards at x=3 m
-    >>> external_force = PointLoad(-30, 3, 0)
+    >>> # 100 N towards the right at x = 9 m
+    >>> external_force = PointLoad(100, 9, 90)
+    >>> # 300 N downwards at x = 3 m
+    >>> external_force = PointLoad(-300, 3, 0)
     >>> external_force
-        PointLoad(force=-30, coord=3, angle=0)
-    
+        PointLoad(force=-300, coord=3, angle=0)
     """
 
     def __init__(self, force=0, coord=0, angle=0):
@@ -154,10 +154,10 @@ class UDL(Load):
     Parameters
     ----------
     force : int, optional
-        UDL load in kN/m, by default 0
+        UDL load (default units N/m), by default 0
     span: tuple of floats
         A tuple containing the starting and ending coordinate that
-        the UDL is applied to.
+        the UDL is applied to (default units m).
     angle: float
         angle of point load where:
         - 0 degrees is purely horizontal +ve
@@ -166,8 +166,8 @@ class UDL(Load):
 
     Examples
     --------
-    >>> # load of 1 kN/m from 1 <= x <= 4 (vertical)
-    >>> self_weight = UDL(1, (1, 4), 90)
+    >>> # load of 1000 N/m from 1 m <= x <= 4 m (vertical)
+    >>> self_weight = UDL(1000, (1, 4), 90)
     """
 
     def __init__(self, force=0, span=(0, 0), angle=0):
@@ -216,10 +216,10 @@ class TrapezoidalLoad(Load):
     ----------
     force : tuple of floats
         A tuple containing the starting and ending loads of
-        the trapezoidal load in kN/m.
+        the trapezoidal load (default units N/m).
     span: tuple of floats
         A tuple containing the starting and ending coordinate that
-        the trapezoidal load is applied to.
+        the trapezoidal load is applied to (default units m).
     angle: float
         angle of point load where:
         - 0 degrees is purely horizontal +ve
@@ -228,9 +228,9 @@ class TrapezoidalLoad(Load):
 
     Examples
     --------
-    >>> # trapezoidal load starting at 2 kN/m at 1 m and ending at 3 kN/m
+    >>> # trapezoidal load starting at 2000 N/m at 1 m and ending at 3000 N/m
     >>> # at 4 m (vertical)
-    >>> self_weight = UDL((2,3), (1, 4), 90)
+    >>> self_weight = UDL((2000, 3000), (1, 4), 90) 
     """
 
     def __init__(self, force=(0, 0), span=(0, 0), angle=0):
@@ -308,19 +308,20 @@ class DistributedLoad(Load):
     expr: sympy expression
         Sympy expression of the distributed load function expressed
         using variable x which represents the beam x-coordinate.
-        Requires quotation marks around expression.
+        Requires quotation marks around expression (default units in N/m).
     span: tuple of floats
         A tuple containing the starting and ending coordinate that
-         the function is applied to.
+         the function is applied to (default units m).
     angle: float
         angle of point load where:
         - 0 degrees is purely horizontal +ve
         - 90 degrees is purely vertical +ve
         - 180 degrees is purely horizontal -ve of force sign specified.
+
     Examples
     --------
-    >>> # Linearly growing load for 0<x<2 m
-    >>> snow_load = DistributedLoad("10*x+5", (0, 2),90)
+    >>> # Linearly growing load for 0 < x < 2 m
+    >>> snow_load = DistributedLoad("10 * x + 5", (0, 2), 90)
     """
 
     def __init__(self, expr, span=(0, 0), angle=0):
@@ -330,10 +331,11 @@ class DistributedLoad(Load):
             expr = Piecewise((0, x < span[0]), (0, x > span[1]), (expr, True))
             
         except BaseException:
-            print("Can not convert expression to sympy function. \
-            Function should only contain variable x, should be \
-            encapsulated by quotations, and should have * between x \
-            and coefficients i.e 2 * x rather than 2x")
+            print("Can not convert expression to sympy function. "+
+            "Function should only contain variable x, should be " +
+            "encapsulated by quotations, and should have * between x " +
+            "and coefficients i.e 2 * x rather than 2x"
+            )
 
         # Validate span input
         assert_length(span, 2, 'span')
@@ -364,14 +366,16 @@ class PointLoadV(PointLoad):
     Parameters:
     -----------
     Force: float
-        Force in kN
+        Force load (default units N)
     coord: float
-        x coordinate of load on beam
+        x coordinate of load on beam (default units m)
 
     Examples
     --------
-    >>> # 10 kN towards the right at x=9 m
-    >>> external_force = PointLoad(10, 9)
+    >>> # 100 N towards the right at x = 9 m
+    >>> external_force = PointLoad(100, 9)
+
+    Note: Positive force acts up.
     """
 
     def __init__(self, force=0, coord=0):
@@ -384,14 +388,16 @@ class PointLoadH(PointLoad):
     Parameters:
     -----------
     Force: float
-        Force in kN
+        Force load (default units m)
     coord: float
-        x coordinate of load on beam
+        x coordinate of load on beam (default units m)
 
     Examples
     --------
-    >>> # 10 kN up at x=9 m
-    >>> external_force = PointLoad(10, 9)
+    >>> # 100 N up at x = 9 m
+    >>> external_force = PointLoad(100, 9)
+
+    Note: Positive force acts right.
     """
 
     def __init__(self, force=0, coord=0):
@@ -403,16 +409,18 @@ class UDLV(UDL):
     
     Parameters
     ----------
-    force : int, optional
-        UDL load in kN/m, by default 0
+    Force: float
+        Force load (default units N/m)
     span: tuple of floats
         A tuple containing the starting and ending coordinate that
-        the UDL is applied to.
+        the UDL is applied to (default units m).
 
     Examples
     --------
-    >>> # load of 1 kN/m (acting down) from 1 <= x <= 4 
-    >>> self_weight = UDL(-1, (1, 4))
+    >>> # load of 1000 N/m (acting down) from 1 <= x <= 4 m
+    >>> self_weight = UDL(-1000, (1, 4))
+
+    Note: Positive force acts up.
     """
 
     def __init__(self, force=0, span=(0, 0)):
@@ -424,16 +432,18 @@ class UDLH(UDL):
     
     Parameters
     ----------
-    force : int, optional
-        UDL load in kN/m, by default 0
+    Force: float
+        Force load (default units N/m)
     span: tuple of floats
         A tuple containing the starting and ending coordinate that
-        the UDL is applied to.
+        the UDL is applied to (default units m).
 
     Examples
     --------
-    >>> # load of 2 kN/m (acting right) from 1 <= x <= 4 (vertical)
-    >>> self_weight = UDL(2, (1, 4))
+    >>> # load of 1000 N/m (acting right) from 1 <= x <= 4 m
+    >>> self_weight = UDL(-1000, (1, 4))
+
+    Note: Positive force acts right.
     """
 
     def __init__(self, force=0, span=(0, 0)):
@@ -447,16 +457,18 @@ class TrapezoidalLoadV(TrapezoidalLoad):
     ----------
     force : tuple of floats
         A tuple containing the starting and ending loads of
-        the trapezoidal load in kN/m.
+        the trapezoidal load (default units N/m).
     span: tuple of floats
         A tuple containing the starting and ending coordinate that
-        the trapezoidal load is applied to.
+        the trapezoidal load is applied to (default units m).
 
     Examples
     --------
-    >>> # trapezoidal load starting at 2 kN/m at 1 m and ending at 3 kN/m
+    >>> # trapezoidal load starting at 2000 N/m at 1 m and ending at 3000 N/m
     >>> # at 4 m (acting down)
-    >>> self_weight = UDL((-2,-3), (1, 4), 90)
+    >>> self_weight = UDL((-2000,-3000), (1, 4))
+
+    Note: Positive force acts up.
     """
 
     def __init__(self, force=(0, 0), span=(0, 0)):
@@ -470,16 +482,18 @@ class TrapezoidalLoadH(TrapezoidalLoad):
     ----------
     force : tuple of floats
         A tuple containing the starting and ending loads of
-        the trapezoidal load in kN/m.
+        the trapezoidal load (default units N/m).
     span: tuple of floats
         A tuple containing the starting and ending coordinate that
-        the trapezoidal load is applied to.
+        the trapezoidal load is applied to (default units m).
 
     Examples
     --------
-    >>> # trapezoidal load starting at 2 kN/m at 1 m and ending at 3 kN/m
+    >>> # trapezoidal load starting at 2000 N/m at 1 m and ending at 3 N/m
     >>> # at 4 m (acting right)
-    >>> self_weight = UDL((2,3), (1, 4))
+    >>> self_weight = UDL((2000, 3000), (1, 4))
+
+    Note: Positive force acts right.
     """
 
     def __init__(self, force=(0, 0), span=(0, 0)):
@@ -494,16 +508,18 @@ class DistributedLoadV(DistributedLoad):
     -----------
     expr: sympy expression
         Sympy expression of the distributed load function expressed
-        using variable x which represents the beam x-coordinate.
-        Requires quotation marks around expression.
+        using variable x which represents the beam x-coordinate (default
+        units N/m).Requires quotation marks around expression.
     span: tuple of floats
         A tuple containing the starting and ending coordinate that
-         the function is applied to.
+         the function is applied to (default units m).
    
     Examples
     --------
-    >>> # Linearly growing load (acting down) for 0<x<2 m
+    >>> # Linearly growing load (acting down) for 0 < x < 2 m
     >>> snow_load = DistributedLoad("-10*x-5", (0, 2))
+
+    Note: Positive force acts up.
     """
 
     def __init__(self, expr=0, span=(0, 0)):
@@ -518,16 +534,18 @@ class DistributedLoadH(DistributedLoad):
     -----------
     expr: sympy expression
         Sympy expression of the distributed load function expressed
-        using variable x which represents the beam x-coordinate.
-        Requires quotation marks around expression.
+        using variable x which represents the beam x-coordinate (default
+        units N/m). Requires quotation marks around expression.
     span: tuple of floats
         A tuple containing the starting and ending coordinate that
-         the function is applied to.
+         the function is applied to (default units m).
    
     Examples
     --------
-    >>> # Linearly growing load (acting right) for 0<x<2 m
+    >>> # Linearly growing load (acting right) for 0 < x < 2 m
     >>> snow_load = DistributedLoad("10*x+5", (0, 2))
+
+    Note: Positive force acts right.
     """
 
     def __init__(self, expr=0, span=(0, 0)):
